@@ -13,32 +13,33 @@ import pygsheets
 
 class Connection:
     """
-    Establishes authentication for google API products
-
-    Needs the client_secret.json from the Google Developer Console
+    Google API Wrapper for Google Connection Resource Objects
+    REMEMBER your 'client_secret.json' file in your PATH
     
-    Class will create a folder in the CWD (if it doesn't exist)
-    Authenticate via oAuth2.0
-    Return a resource object to be used in the other wrapper classes
+    Creates a folder in the CWD (if it doesn't exist),
+    Authenticate via oAuth2.0,
+    Returns a resource object to be used in the other wrapper classes
 
-    Current methods for authenication
-    .gsc()
-    .ga()
-    .cal()
-    .sheets()
-    .gbq() * requires a separate service account authentication file * 
-    .gmail()
+    __Current methods used for authenication__
+    .gsc() -> Google Search Console
+    .ga() -> Google Analytics
+    .cal() -> Google Calendar
+    .sheets() -> Google Sheets
+    .gbq()** -> Google Big Query
+    .gmail() -> Gmail
+
+    ** requires a separate service account authentication file **
     """
-    def __init__(self, file_path="client_secret.json"):
+    def __init__(self, file_path="client_secret.json") -> None:
         self.file_path = file_path
-        self.dir_check()
+        self.__dir_check()
 
-    def dir_check(self) -> None:
+    def __dir_check(self) -> None:
         # if there isn't a crednetials folder, create one
         if not Path("./credentials/").is_dir():
             Path("./credentials/").mkdir()
 
-    def authenticate(self, scope, token_name,http_return=True):
+    def _authenticate(self, scope:list, token_name:str, http_return:bool = True):
         """
         Authenticates Google Product using oauth2
         Saves the credentials in the ./credentials folder
@@ -88,18 +89,18 @@ class Connection:
     def gsc(self):
         scope_list = ["https://www.googleapis.com/auth/webmasters.readonly"]
         return build(
-            "webmasters", "v3", http=self.authenticate(scope_list, "search_console")
+            "webmasters", "v3", http=self._authenticate(scope_list, "search_console")
         )
 
     def ga(self):
         scope_list = ["https://www.googleapis.com/auth/analytics.readonly"]
         return build(
-            "analyticsreporting", "v4", http=self.authenticate(scope_list, "analytics")
+            "analyticsreporting", "v4", http=self._authenticate(scope_list, "analytics")
         )
 
     def cal(self):
         scope_list = ["https://www.googleapis.com/auth/calendar"]
-        return build("calendar", "v3", http=self.authenticate(scope_list, "calendar"))
+        return build("calendar", "v3", http=self._authenticate(scope_list, "calendar"))
 
     def pygsheets(self):
         return pygsheets.authorize(local=True,credentials_directory='./credentials/')
@@ -109,11 +110,11 @@ class Connection:
             "https://www.googleapis.com/auth/drive",
             "https://www.googleapis.com/auth/spreadsheets",
         ]
-        return build("sheets", "v4", http=self.authenticate(scope_list, "sheets"))
+        return build("sheets", "v4", http=self._authenticate(scope_list, "sheets"))
 
     def gbq(self, sa_file_path="gbq-sa.json"):
         return service_account.Credentials.from_service_account_file(sa_file_path)
 
     def gmail(self):
         scope_list = ["https://mail.google.com/"]
-        return build("gmail", "v1", http=self.authenticate(scope_list, "gmail"))
+        return build("gmail", "v1", http=self._authenticate(scope_list, "gmail"))
