@@ -1,4 +1,4 @@
-from googlewrapper.connect import Connection
+from .connect import Connection
 from email.mime.text import MIMEText
 from base64 import urlsafe_b64encode
 
